==> huaweicloudsdkces-3.0.49-py2.py3-none-any.whl: huaweicloudsdkces/v1/model/update_alarm_template_request.py <==
# coding: utf-8

import pprint
import re

import six





class UpdateAlarmTemplateRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'template_id': 'str',
        'body': 'UpdateAlarmTemplateRequestBody'
    }

    attribute_map = {
        'template_id': 'template_id',
        'body': 'body'
    }

    def __init__(self, template_id=None, body=None):
        """UpdateAlarmTemplateRequest - a model defined in huaweicloud sdk"""
        
        

        self._template_id = None
        self._body = None
        self.discriminator = None

        self.template_id = template_id
        if body is not None:
            self.body = body

    @property
    def template_id(self):
        """Gets the template_id of this UpdateAlarmTemplateRequest.

        需要更新的自定义告警模板ID。

        :return: The template_id of this UpdateAlarmTemplateRequest.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this UpdateAlarmTemplateRequest.

        需要更新的自定义告警模板ID。

        :param template_id: The template_id of this UpdateAlarmTemplateRequest.
        :type: str
        """
        self._template_id = template_id

    @property
    def body(self):
        """Gets the body of this UpdateAlarmTemplateRequest.


        :return: The body of this UpdateAlarmTemplateRequest.
        :rtype: UpdateAlarmTemplateRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateAlarmTemplateRequest.


        :param body: The body of this UpdateAlarmTemplateRequest.
        :type: UpdateAlarmTemplateRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAlarmTemplateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkces-3.0.51-py2.py3-none-any.whl: huaweicloudsdkces/v1/model/update_alarm_template_request.py <==
# coding: utf-8

import re
import six





class UpdateAlarmTemplateRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'template_id': 'str',
        'body': 'UpdateAlarmTemplateRequestBody'
    }

    attribute_map = {
        'template_id': 'template_id',
        'body': 'body'
    }

    def __init__(self, template_id=None, body=None):
        """UpdateAlarmTemplateRequest - a model defined in huaweicloud sdk"""
        
        

        self._template_id = None
        self._body = None
        self.discriminator = None

        self.template_id = template_id
        if body is not None:
            self.body = body

    @property
    def template_id(self):
        """Gets the template_id of this UpdateAlarmTemplateRequest.

        需要更新的自定义告警模板ID。

        :return: The template_id of this UpdateAlarmTemplateRequest.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this UpdateAlarmTemplateRequest.

        需要更新的自定义告警模板ID。

        :param template_id: The template_id of this UpdateAlarmTemplateRequest.
        :type: str
        """
        self._template_id = template_id

    @property
    def body(self):
        """Gets the body of this UpdateAlarmTemplateRequest.


        :return: The body of this UpdateAlarmTemplateRequest.
        :rtype: UpdateAlarmTemplateRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateAlarmTemplateRequest.


        :param body: The body of this UpdateAlarmTemplateRequest.
        :type: UpdateAlarmTemplateRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAlarmTemplateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
